import net.idrnd.idliveface.*;

import java.nio.file.Path;
import java.nio.file.Paths;

public class Example {
    private static final Path IDLIVEFACE_HOME = Paths.get("/opt/idliveface");

    private final ImageDecoder decoder;
    private final FaceAnalyzer analyzer;

    public FaceAnalyzerExample() {
        try (Blueprint blueprint = new Blueprint(IDLIVEFACE_HOME.resolve("data"))) {
            System.out.println("Initializing...");
            decoder = blueprint.createImageDecoder();
            analyzer = blueprint.createFaceAnalyzer();
        }
    }

    public void run() {
        System.out.println("\nAnalyzing real_face.jpg");

        try (Image image =
                decoder.decodeFile(IDLIVEFACE_HOME.resolve("examples/images/real_face.jpg"))) {
            FaceAnalysisResult result = analyzer.analyze(image);
            processResult(result);
        }

        System.out.println("\nAnalyzing spoof_face.jpg");

        try (Image image =
                decoder.decodeFile(IDLIVEFACE_HOME.resolve("examples/images/spoof_face.jpg"))) {
            FaceAnalysisResult result = analyzer.analyze(image);
            processResult(result);
        }

        System.out.println("\nAnalyzing face_is_occluded.jpg");

        try (Image image =
                decoder.decodeFile(IDLIVEFACE_HOME.resolve("examples/images/face_is_occluded.jpg"))) {
            FaceAnalysisResult result = analyzer.analyze(image);
            processResult(result);
        }
    }

    private static void processResult(FaceAnalysisResult result) {
        System.out.println("Result: " + result);

        if (result.getStatus() != FaceStatus.INVALID) {
            System.out.println(
                    "Image is " + result.getStatus() + ", probability is " + result.getGenuineProbability().get());
        } else {
            System.out.println("Image did not pass validations and is not suitable for analysis");
            System.out.println("Failed validations: " + result.getFailedValidations());
        }
    }

    public static void main(String[] args) {
        FaceAnalyzerExample example = new FaceAnalyzerExample();
        example.run();
    }
}
